==> gromacs_5.0.4.orig.tar.gz: gromacs-5.0.4/src/gromacs/fileio/timecontrol.c <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team.
 * Copyright (c) 2013,2014, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
#include "gromacs/fileio/timecontrol.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "thread_mpi/threads.h"

#include "gromacs/legacyheaders/types/simple.h"
#include "gromacs/legacyheaders/gmx_fatal.h"

/* The source code in this file should be thread-safe.
         Please keep it that way. */

/* Globals for trajectory input */
typedef struct {
    real     t;
    gmx_bool bSet;
} t_timecontrol;

static t_timecontrol       timecontrol[TNR] = {
    { 0, FALSE },
    { 0, FALSE },
    { 0, FALSE }
};

static tMPI_Thread_mutex_t tc_mutex = TMPI_THREAD_MUTEX_INITIALIZER;

gmx_bool bTimeSet(int tcontrol)
{
    gmx_bool ret;

    tMPI_Thread_mutex_lock(&tc_mutex);
    range_check(tcontrol, 0, TNR);
    ret = timecontrol[tcontrol].bSet;
    tMPI_Thread_mutex_unlock(&tc_mutex);

    return ret;
}

real rTimeValue(int tcontrol)
{
    real ret;

    tMPI_Thread_mutex_lock(&tc_mutex);
    range_check(tcontrol, 0, TNR);
    ret = timecontrol[tcontrol].t;
    tMPI_Thread_mutex_unlock(&tc_mutex);
    return ret;
}

void setTimeValue(int tcontrol, real value)
{
    tMPI_Thread_mutex_lock(&tc_mutex);
    range_check(tcontrol, 0, TNR);
    timecontrol[tcontrol].t    = value;
    timecontrol[tcontrol].bSet = TRUE;
    tMPI_Thread_mutex_unlock(&tc_mutex);
}

==> gromacs_5.1.2.orig.tar.gz: gromacs-5.1.2/src/gromacs/fileio/timecontrol.c <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team.
 * Copyright (c) 2013,2014, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
#include "gmxpre.h"

#include "timecontrol.h"

#include "thread_mpi/threads.h"

#include "gromacs/utility/basedefinitions.h"
#include "gromacs/utility/fatalerror.h"
#include "gromacs/utility/real.h"

/* The source code in this file should be thread-safe.
         Please keep it that way. */

/* Globals for trajectory input */
typedef struct {
    real     t;
    gmx_bool bSet;
} t_timecontrol;

static t_timecontrol       timecontrol[TNR] = {
    { 0, FALSE },
    { 0, FALSE },
    { 0, FALSE }
};

static tMPI_Thread_mutex_t tc_mutex = TMPI_THREAD_MUTEX_INITIALIZER;

gmx_bool bTimeSet(int tcontrol)
{
    gmx_bool ret;

    tMPI_Thread_mutex_lock(&tc_mutex);
    range_check(tcontrol, 0, TNR);
    ret = timecontrol[tcontrol].bSet;
    tMPI_Thread_mutex_unlock(&tc_mutex);

    return ret;
}

real rTimeValue(int tcontrol)
{
    real ret;

    tMPI_Thread_mutex_lock(&tc_mutex);
    range_check(tcontrol, 0, TNR);
    ret = timecontrol[tcontrol].t;
    tMPI_Thread_mutex_unlock(&tc_mutex);
    return ret;
}

void setTimeValue(int tcontrol, real value)
{
    tMPI_Thread_mutex_lock(&tc_mutex);
    range_check(tcontrol, 0, TNR);
    timecontrol[tcontrol].t    = value;
    timecontrol[tcontrol].bSet = TRUE;
    tMPI_Thread_mutex_unlock(&tc_mutex);
}
